using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;

namespace BasicSteemaTeechart
{
    
        /// <summary>
        /// Overrides the Steema Teechart Line style to provide support 
        /// for custom data quality functionality.
        /// </summary>
    public class DQLine : Steema.TeeChart.Styles.Line
    {
        public System.Collections.Hashtable samplesByIndex = new System.Collections.Hashtable();
        private System.Collections.Hashtable samplesByDate = new System.Collections.Hashtable();
        public System.Collections.Hashtable penStyles = new System.Collections.Hashtable();
        public System.Collections.Hashtable penColors = new System.Collections.Hashtable();
        public System.Collections.Hashtable prevPenColors = new System.Collections.Hashtable();
        private System.Drawing.Color lineColor = Color.Empty;

        public System.Drawing.Color LineColor
        {
            get
            {
                return lineColor;
            }
            set
            {
                lineColor = value;
            }
        }

        /// <summary>
        /// Default constructor.
        /// </summary>
        public DQLine() : this(null) { }

        /// <summary>
        /// Constructor that sets the chart graphics instance.
        /// </summary>
        /// <param name="c">Steema chart instance.</param>
        public DQLine(Steema.TeeChart.Chart c)
            : base(c)
        {
        }

        /// <summary>
        /// Override the Steema line style Draw() method.
        /// </summary>
        protected override void Draw()
        {
            base.Draw();
        }

        /// <summary>
        /// Add a sample to the series.
        /// </summary>
        /// <param name="x">Datetime X-axis value.</param>
        /// <param name="y">Y-axis value.</param>
        /// <param name="color">Sample color.</param>
        /// <param name="ds">Sample line style (solid, dashed, dot, etc)</param>
        /// <returns></returns>
        public int Add(DateTime x, double y, Color color, System.Drawing.Drawing2D.DashStyle ds)
        {
            int addIndex = 0;
            if (samplesByIndex.ContainsValue(x) == true)
            {
                penStyles[x] = y;
                penColors[x] = color;
                //Delete(dateSamples.IndexOf(x), 1);
                int count = this.Count;
            }
            else
            {
                if (samplesByIndex.Count == 0)
                {
                    addIndex = Add(x, y, string.Empty, this.Color);
                }
                else
                {
                    addIndex = Add(x, y, string.Empty, (Color)penColors[samplesByIndex[samplesByIndex.Count - 1]]);
                }
            }
            if (samplesByIndex.ContainsKey(addIndex) == false)
            {
                samplesByIndex.Add(addIndex, x);
                samplesByDate.Add(x, addIndex);
                //dateSamples.Sort();
                penStyles.Add(x, ds);
                penColors.Add(x, color);
                if (addIndex > 0)
                {
                    prevPenColors.Add(x, (Color)penColors[samplesByIndex[addIndex - 1]]);
                }
            }
            return addIndex;
        }
    }
}
